RouletteController class
- Inheritance
-
- Object
- ChangeNotifier
- RouletteController
Constructors
Properties
- currentAngle → double
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isSpinning → bool
-
no setter
- result → RouletteResult?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
attachSpinHandler(
Future< void> handler(int targetIndex, int itemCount)) → void -
dispose(
) → void -
Discards any resources used by the object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
spin(
List< RouletteItem> items, {Random? random}) → Future<void> -
spinToIndex(
int index, List< RouletteItem> items) → Future<void> -
toString(
) → String -
A string representation of this object.
inherited
-
updateAngle(
double angle) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited